@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Ryu::Node);
 
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 =head1 NAME
 
@@ -391,38 +391,6 @@ sub throw {
     $src->fail('...');
 }
 
-=head2 pause
-
-Does nothing useful.
-
-=cut
-
-sub pause {
-    my $self = shift;
-    $self->{is_paused} = 1;
-    $self
-}
-
-=head2 resume
-
-Is about as much use as L</pause>.
-
-=cut
-
-sub resume {
-    my $self = shift;
-    $self->{is_paused} = 0;
-    $self
-}
-
-=head2 is_paused
-
-Might return 1 or 0, but is generally meaningless.
-
-=cut
-
-sub is_paused { $_[0]->{is_paused} }
-
 =head2 debounce
 
 Not yet implemented.
@@ -1610,9 +1578,10 @@ sub emit {
     use namespace::clean qw(try catch finally);
     my $self = shift;
     my $completion = $self->completed;
+    my @handlers = @{$self->{on_item} || []} or return $self;
     for (@_) {
-        for my $code (@{$self->{on_item}}) {
-            die 'already completed' if $completion->is_ready;
+        die 'already completed' if $completion->is_ready;
+        for my $code (@handlers) {
             try {
                 $code->($_);
             } catch {
@@ -1719,10 +1688,6 @@ sub notify_child_completion {
     $self
 }
 
-sub label { shift->{label} }
-
-sub parent { shift->{parent} }
-
 =head2 await
 
 Block until this source finishes.
@@ -1742,7 +1707,7 @@ Mark this source as completed.
 
 =cut
 
-sub finish { $_[0]->completed->done; $_[0] }
+sub finish { $_[0]->completed->done unless $_[0]->completed->is_ready; $_[0] }
 
 sub refresh { }
 
